<?php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;
use App\Models\User;

class CustomAuthController extends Controller
{
    public function index()
    {
        return view('admin.auth.login');
    }  
      
    public function customLogin(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'password' => 'required',
        ]);
   
        $credentials = $request->only('name', 'password');
        if (Auth::attempt($credentials)) {
            return redirect()->intended('admin/dashboard')
                        ->withSuccess('Signed in');
        }
  
        return redirect("/admin")->withSuccess('Login details are not valid');
    }

    public function registration()
    {
        return view('admin.auth.registration');
    }
      
    public function customRegistration(Request $request)
    {  
        $request->validate([
            'name' => 'required',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:6',
        ]);
           
        $data = $request->all();
        $check = $this->create($data);
         
        return redirect("admin/dashboard")->withSuccess('You have signed-in');
    }

    public function create(array $data)
    {
      return User::create([
        'name' => $data['name'],
        'email' => $data['email'],
        'password' => Hash::make($data['password'])
      ]);
    }    
    
    public function dashboard()
    {
        if(Auth::check()){
            return view('admin.backend.layout.dashboard');
        }
  
        return redirect("admin/login")->withSuccess('You are not allowed to access');
    }
    
    public function signOut()
{
    Auth::logout(); 
    session()->forget(['admin_key']); 
    
    return redirect('/admin');
}




   
    public function showChangePasswordForm()
    {
        return view('admin.change_password');
    }

    public function updatePassword(Request $request)
    {
        $request->validate([
            'current_password' => 'required',
            'new_password' => 'required|string|min:8|confirmed',
        ]);
    
        $user = Auth::user();
    
        if (Hash::check($request->current_password, $user->password)) {
            if ($request->current_password == $request->new_password) {
                return redirect()->route('admin.show.change.password.form')->with('error', 'New password must be different from the current password.');
            }
    
            $user->update([
                'password' => Hash::make($request->new_password),
            ]);
    
            return redirect()->route('admin.show.change.password.form')->with('success', 'Password changed successfully.');
        }
    
        return redirect()->route('admin.show.change.password.form')->with('error', 'Current password is incorrect.');
    }
    
}