<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Validator;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;
use App\Mail\OrderNotification; 
use App\Models\tbl_page;
use App\Models\tbl_banner;
use App\Models\location;
use App\Models\partners;
use App\Models\Order;
use App\Models\bar_club_added;
use App\Models\websiteMange;
use Illuminate\Support\Str;
use Carbon\Carbon;

class OrderController extends Controller
{
   
public function OrderFormData(Request $request)
{
    try {
        
        $request->validate([
            'username' => 'required',
            'email' => 'required|email',
            'email_address' => 'required|email', 
        ]);

       
        $bookTime = Carbon::createFromFormat('g:ia', $request->book_time)->format('H:i:s');
        $bookDate = Carbon::createFromFormat('m/d/Y', $request->book_date)->format('Y-m-d');

       
        do {
            $randomOrderId = 'ORD-' . random_int(100000, 999999);
        } while (Order::where('order_id', $randomOrderId)->exists());

      
        $orderData = Order::create([
            'username' => $request->username,
            'order_id' => $randomOrderId,
            'email' => $request->email,
            'phone' => $request->phone,
            'offer' => $request->offer,
            'person' => $request->person,
            'email_address' => $request->email_address,
            'book_date' => $bookDate,
            'book_time' => $bookTime,
            'description' => $request->description,
            'register_id_u' => $request->register_id_u,
            'register_id_p' => $request->register_id_p,
            'status' => 'active',
        ]);

        
        session([
            'register_id_u' => $orderData->register_id_u,
            'username' => $orderData->username,
        ]);

       
        Mail::to($request->email_address)->send(new OrderNotification($orderData));

        return response()->json([
            'success' => true,
            'message' => 'Order placed successfully. An email notification has been sent.',
            'session' => [
                'register_id_u' => session('register_id_u'),
                'username' => session('username'),
            ],
        ]);
    } catch (\Exception $e) {
      
        return response()->json([
            'success' => false,
            'message' => 'An error occurred: ' . $e->getMessage(),
        ]);
    }
}


public function OrderFormSecondData(Request $request)
{
    try {
        
        $request->validate([
            'username' => 'required',
            'email' => 'required|email',
            'email_address' => 'required|email', 
        ]);

       
        $bookTime = Carbon::createFromFormat('g:ia', $request->book_time)->format('H:i:s');
        $bookDate = Carbon::createFromFormat('m/d/Y', $request->book_date)->format('Y-m-d');

       
        do {
            $randomOrderId = 'ORD-' . random_int(100000, 999999);
        } while (Order::where('order_id', $randomOrderId)->exists());

      
        $orderData = Order::create([
            'username' => $request->username,
            'order_id' => $randomOrderId,
            'email' => $request->email,
            'phone' => $request->phone,
            'person' => $request->person,
            'email_address' => $request->email_address,
            'book_date' => $bookDate,
            'book_time' => $bookTime,
            'description' => $request->description,
            'register_id_u' => $request->register_id_u,
            'register_id_p' => $request->register_id_p,
            'status' => 'active',
        ]);

        
        session([
            'register_id_u' => $orderData->register_id_u,
            'username' => $orderData->username,
        ]);

       
        Mail::to($request->email_address)->send(new OrderNotification($orderData));

        return response()->json([
            'success' => true,
            'message' => 'Order placed successfully. An email notification has been sent.',
            'session' => [
                'register_id_u' => session('register_id_u'),
                'username' => session('username'),
            ],
        ]);
    } catch (\Exception $e) {
      
        return response()->json([
            'success' => false,
            'message' => 'An error occurred: ' . $e->getMessage(),
        ]);
    }
}


}
