<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Log;
use Validator;
use App\Mail\PartnerOtpMail;
use Illuminate\Support\Facades\Mail;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\DB;
use App\Models\tbl_page;
use App\Models\tbl_banner;
use App\Models\location;
use App\Models\partners;
use App\Models\bar_club_added;
use App\Models\websiteMange;
use Illuminate\Support\Str;

class PartnerWithUsController extends Controller
{
    


public function PartnerRegisterFrom(Request $request)
{
    try {
     
        $request->validate([
            'username' => 'required|unique:partners,username',
            'email_address' => 'required|email|unique:partners,email_address',
            'password' => 'required|min:6',
            'bar_club' => 'required',
        ]);

      
        $lastRegisterId = partners::where('register_id', 'LIKE', 'FRZ-P%')
            ->selectRaw("CAST(SUBSTRING(register_id, 6) AS UNSIGNED) AS id_number")
            ->orderByDesc('id_number')
            ->value('id_number');
        
        $newIdNumber = $lastRegisterId ? $lastRegisterId + 1 : 1;
        $newRegisterId = 'FRZ-P' . str_pad($newIdNumber, 2, '0', STR_PAD_LEFT);

     
        $otp = random_int(100000, 999999);

       
        $partner = partners::create([
            'bar_club' => $request->bar_club,
            'bar_club_url' => Str::slug($request->bar_club),
            'register_id' => $newRegisterId,
            'username' => $request->username,
            'password' => bcrypt($request->password),
            'address' => $request->address,
            'manger_owner_name' => $request->manger_owner_name,
            'contact_no' => $request->contact_no,
            'alternate_no' => $request->alternate_no,
            'email_address' => $request->email_address,
            'location' => $request->location,
            'location_url' => Str::slug($request->location),
            'type_of_venu' => $request->type_of_venu,
            'guest_capacity' => $request->guest_capacity,
            'opening_time' => $request->opening_time,
            'closing_time' => $request->closing_time,
            'otp' => $otp, 
            'status' => 'pending',
        ]);

        
        session(['otp' => $otp, 'partner_id' => $partner->partner_id]);

        
        Mail::to($partner->email_address)->send(new PartnerOtpMail($otp));

        
        session([
    'partner_id' => $partner->partner_id,
    'bar_club' => strtolower(str_replace(' ', '-', $partner->bar_club)),
    'register_id' => $partner->register_id,
]);


        return response()->json(['status' => 'success', 'message' => 'OTP sent to your email!']);
    } catch (\Exception $e) {
        return response()->json(['status' => 'error', 'message' => 'An error occurred: ' . $e->getMessage()]);
    }
}


public function PartnerverifyOtp(Request $request)
{
    try {
        
        $request->validate(['otp' => 'required|digits:6']);

       
        $partnerId = session('partner_id');
        if (!$partnerId) {
            return response()->json([
                'status' => 'error',
                'message' => 'Session expired. Please log in again.',
            ]);
        }

        
        $partner = partners::find($partnerId);
        if (!$partner) {
            return response()->json([
                'status' => 'error',
                'message' => 'Partner not found.',
            ]);
        }

        
        if ($partner->otp !== $request->otp) {
            return response()->json([
                'status' => 'error',
                'message' => 'Invalid OTP. Please try again.',
            ]);
        }

     
        
        DB::table('partners')
    ->where('partner_id', $partner->partner_id)
    ->update(['status' => 'active', 'otp' => null]);


        
        session([
            'partner_id' => $partner->partner_id,
            'bar_club' => strtolower(str_replace(' ', '-', $partner->bar_club)),
            'register_id' => $partner->register_id,
        ]);

      
        return response()->json([
            'status' => 'success',
            'message' => 'OTP verified successfully!',
            'redirect' => route('partner-profile', [
                'clubname' => session('bar_club'),
                'register_id' => session('register_id'),
            ]),
        ]);
    } catch (\Exception $e) {
    
        return response()->json([
            'status' => 'error',
            'message' => 'An unexpected error occurred: ' . $e->getMessage(),
        ]);
    }
}






public function showPartnerLoginForm()
{
    return view('partner.login'); 
}

public function partnerLogin(Request $request)
{
    $request->validate([
        'username' => 'required',
        'password' => 'required',
    ]);

    $credentials = $request->only('username', 'password');

    $partner = partners::where('username', $credentials['username'])->first();

    if ($partner && Hash::check($credentials['password'], $partner->password)) {
        session([
            'partner_id' => $partner->partner_id,
            'bar_club' => strtolower(str_replace(' ', '-', $partner->bar_club)),
            'register_id' => $partner->register_id,
        ]);

        return response()->json([
            'success' => true,
            'message' => 'Welcome!',
            'redirect_url' => route('partner-profile', [
                'clubname' => session('bar_club'),
                'register_id' => session('register_id'),
            ]),
        ]);
    }

    return response()->json([
        'success' => false,
        'message' => 'Invalid login credentials.',
    ]);
}




public function partnerLogout()
{
    session()->forget(['partner_id', 'clubname', 'register_id', 'partner_name']);
    

    return redirect()->route('home')->withSuccess('Logged out successfully.');
}



public function PartnerInfoAdd(Request $request)
{
    try {
       $validatedData = $request->validate([
    'cover_images' => 'nullable|image|max:2048',
    'multiple_images.*' => 'nullable|image|max:2048',
    
    ]);

        $existingClub = bar_club_added::where('register_id', $request->register_id)->first();

        $cover_image = $existingClub->cover_images ?? null;
        if ($request->hasFile("cover_images")) {
            $cover_image = rand() . "." . $request->file("cover_images")->getClientOriginalExtension();
            $request->file("cover_images")->move(public_path("/images"), $cover_image);
        }

        $multiple_images = $existingClub ? json_decode($existingClub->multiple_images, true) : [];
        if ($request->hasFile('multiple_images')) {
            foreach ($request->file('multiple_images') as $file) {
                $image_name = rand() . "." . $file->getClientOriginalExtension();
                $file->move(public_path("/images"), $image_name);
                $multiple_images[] = $image_name;
            }
        } 
        
        


        $barSlug = Str::slug($request->bar_title);

        $club = bar_club_added::firstOrNew(['register_id' => $request->register_id]);
        $club->cover_images = $cover_image;
        $club->multiple_images = json_encode($multiple_images);
        
        $club->status = 'active';
        $club->bar_title = $request->bar_title;
        $club->title_url = $barSlug; 
        $club->bar_second_title = $request->bar_second_title;
        $club->save();

        session([
            'register_id' => $club->register_id,
        ]);

        return back()->with('success', 'Record updated successfully!');
    } catch (\Exception $e) {
      
        return back()->with('error', 'An error occurred: ' . $e->getMessage());
    }
}



public function PartnerSecdInfoAdd(Request $request)
{
    try {
        $validatedData = $request->validate([
            'food_image' => 'nullable|array',
            'food_image.*' => 'nullable|image|max:2048',
            'drink_image' => 'nullable|array',
            'drink_image.*' => 'nullable|image|max:2048',
            'menu_images' => 'nullable|array',
            'menu_images.*' => 'nullable|image|max:2048',
        ]);

        $existingClub = bar_club_added::where('register_id', $request->register_id)->first();

        // Handle food images
        $food_images = $existingClub ? json_decode($existingClub->food_image, true) : [];
        if ($request->hasFile('food_image')) {
            foreach ($request->file('food_image') as $file) {
                if ($file->isValid()) {
                    $image_name = rand() . "." . $file->getClientOriginalExtension();
                    $file->move(public_path("/images"), $image_name);
                    $food_images[] = $image_name;
                }
            }
        }

        // Handle drink images
        $drink_images = $existingClub ? json_decode($existingClub->drink_image, true) : [];
        if ($request->hasFile('drink_image')) {
            foreach ($request->file('drink_image') as $file) {
                if ($file->isValid()) {
                    $image_name = rand() . "." . $file->getClientOriginalExtension();
                    $file->move(public_path("/images"), $image_name);
                    $drink_images[] = $image_name;
                }
            }
        }

        // Handle menu images
        $menu_images = $existingClub ? json_decode($existingClub->menu_images, true) : [];
        if ($request->hasFile('menu_images')) {
            foreach ($request->file('menu_images') as $file) {
                if ($file->isValid()) {
                    $image_name = rand() . "." . $file->getClientOriginalExtension();
                    $file->move(public_path("/images"), $image_name);
                    $menu_images[] = $image_name;
                }
            }
        }
       

        // Update or create the club
        $club = bar_club_added::updateOrCreate(
            ['register_id' => $request->register_id],
            [
                'menu_images' => json_encode($menu_images),
                'menu_type' => $request->menu_type,
                'food_image' => json_encode($food_images),
                'drink_image' => json_encode($drink_images),
            ]
        );

        session(['register_id' => $club->register_id]);

        return back()->with('success', 'Record updated successfully!');
    } catch (\Exception $e) {
        dd($e);
        return back()->with('error', 'An error occurred: ' . $e->getMessage());
    }
}



public function offerAdd(Request $request)
{
    try {
      
       
        $request->validate([
            'register_id' => 'required|exists:bar_club_added,register_id',
            'offer1' => 'nullable|string',
            'offer2' => 'nullable|string',
            'home_offer' => 'nullable|string',
            'price' => 'nullable|string',
            'more_info' => 'nullable|string',
            'specification' => 'nullable|string',
        ]);

      
        $club = bar_club_added::where('register_id', $request->register_id)->firstOrFail();
        
     
    
        $club->update([
            'offer1' => $request->offer1,
            'offer2' => $request->offer2,
            'home_offer' => $request->home_offer,
            'price' => $request->price,
            'more_info' => $request->more_info,
            'specification' => $request->specification
        ]);

        session(['register_id' => $club->register_id]);

        return back()->with('success', 'Record updated successfully!');
    } catch (\Exception $e) {
        dd($e);
       
        return back()->with('error', 'An error occurred: ' . $e->getMessage());
    }
}

public function UpadtePartner(Request $request)
{
    try {
       
        $request->validate([
            'logo_image' => 'nullable|image|max:2048',
            'manger_owner_name' => 'required|string|max:255',
            'bar_club' => 'required',
        ]);

        
        $existingPartner = partners::where('register_id', $request->register_id)->first();

        if (!$existingPartner) {
            return response()->json(['success' => false, 'message' => 'Partner not found.']);
        }

        
        if ($request->hasFile('logo_image')) {
            $logo_image = rand() . '.' . $request->file('logo_image')->getClientOriginalExtension();
            $request->file('logo_image')->move(public_path('/images'), $logo_image);
            $existingPartner->logo_image = $logo_image; 
        }

       
        $existingPartner->bar_club = $request->bar_club;
        $existingPartner->bar_club_url = Str::slug($request->bar_club);
        $existingPartner->address = $request->address;
        $existingPartner->manger_owner_name = $request->manger_owner_name;
        $existingPartner->contact_no = $request->contact_no;
        $existingPartner->alternate_no = $request->alternate_no;
        $existingPartner->email_address = $request->email_address;
        $existingPartner->location = $request->location;
        $existingPartner->location_url = Str::slug($request->location);
        $existingPartner->type_of_venu = $request->type_of_venu;
        $existingPartner->guest_capacity = $request->guest_capacity;
        $existingPartner->opening_time = $request->opening_time;
        $existingPartner->closing_time = $request->closing_time;
        $existingPartner->status = 'active';

        $existingPartner->save(); 

        return response()->json(['success' => true, 'message' => 'Profile updated successfully!']);
    } catch (\Exception $e) {
        return response()->json(['success' => false, 'message' => 'An error occurred: ' . $e->getMessage()]);
    }
}


public function MultideleteImage(Request $request)
{
    $imagePath = $request->input('image_path'); 

    $fullPath = public_path('images/' . $imagePath);

    if (is_file($fullPath)) {
        unlink($fullPath);
    } else {
        return response()->json(['success' => false, 'message' => 'File does not exist or is not a file.']);
    }

  
    DB::table('bar_club_added')
        ->whereJsonContains('multiple_images', $imagePath) 
        ->update([
            'multiple_images' => DB::raw("JSON_REMOVE(multiple_images, JSON_UNQUOTE(JSON_SEARCH(multiple_images, 'one', '$imagePath')))"),
        ]);

    return response()->json(['success' => true, 'message' => 'Image deleted successfully.']);
}

public function MenudeleteImage(Request $request)
{
    $imagePath = $request->input('image_path'); 

    $fullPath = public_path('images/' . $imagePath);

    if (is_file($fullPath)) {
        unlink($fullPath);
    } else {
        return response()->json(['success' => false, 'message' => 'File does not exist or is not a file.']);
    }

  
    DB::table('bar_club_added')
        ->whereJsonContains('menu_images', $imagePath) 
        ->update([
            'menu_images' => DB::raw("JSON_REMOVE(menu_images, JSON_UNQUOTE(JSON_SEARCH(menu_images, 'one', '$imagePath')))"),
        ]);

    return response()->json(['success' => true, 'message' => 'Image deleted successfully.']);
}

public function FooddeleteImage(Request $request)
{
    $imagePath = $request->input('image_path'); 

    $fullPath = public_path('images/' . $imagePath);

    if (is_file($fullPath)) {
        unlink($fullPath);
    } else {
        return response()->json(['success' => false, 'message' => 'File does not exist or is not a file.']);
    }

  
    DB::table('bar_club_added')
        ->whereJsonContains('food_image', $imagePath) 
        ->update([
            'food_image' => DB::raw("JSON_REMOVE(food_image, JSON_UNQUOTE(JSON_SEARCH(food_image, 'one', '$imagePath')))"),
        ]);

    return response()->json(['success' => true, 'message' => 'Image deleted successfully.']);
}

public function DrinkdeleteImage(Request $request)
{
    $imagePath = $request->input('image_path'); 

    $fullPath = public_path('images/' . $imagePath);

    if (is_file($fullPath)) {
        unlink($fullPath);
    } else {
        return response()->json(['success' => false, 'message' => 'File does not exist or is not a file.']);
    }

  
    DB::table('bar_club_added')
        ->whereJsonContains('drink_image', $imagePath) 
        ->update([
            'drink_image' => DB::raw("JSON_REMOVE(drink_image, JSON_UNQUOTE(JSON_SEARCH(drink_image, 'one', '$imagePath')))"),
        ]);

    return response()->json(['success' => true, 'message' => 'Image deleted successfully.']);
}


}