<?php

use Illuminate\Support\Facades\Route;

use App\Http\Controllers\AdminController;
use App\Http\Controllers\CustomAuthController;
use App\Http\Provider\AppServiceProvider;
use App\Http\Controllers\BannerController;
use App\Http\Controllers\HomeController;
use App\Http\Controllers\PartnerWithUsController;
use App\Http\Controllers\CustomerController;
use App\Http\Controllers\BarClubController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\OrderController;
use App\Http\Controllers\FiltersController;
use App\Http\Controllers\OrderListController;
use App\Http\Controllers\ReviewController;
use App\Http\Controllers\SearchController;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/


    
Route::middleware('auth')->group(function () {
    Route::get('admin/dashboard', [AdminController::class, 'dashboard'])->name('admin.dashboard');
    // Other admin routes...
});

//-------------------------------login------------------------------->
Route::get('/admin', [CustomAuthController::class, 'index'])->name('login');
Route::post('/admin/custom-login', [CustomAuthController::class, 'customLogin'])->name('admin.login.custom'); 
//--------------------------------registration------------------------>
Route::get('/admin/registration', [CustomAuthController::class, 'registration'])->name('admin.register-user');
Route::post('admin/custom-registration', [CustomAuthController::class, 'customRegistration'])->name('admin.register.custom'); 
Route::get('admin/signout', [CustomAuthController::class, 'signOut'])->name('admin.signout');
Route::get('/admin/change-password', [CustomAuthController::class, 'showChangePasswordForm'])->name('admin.show.change.password.form');
Route::post('/admin/update-password', [CustomAuthController::class, 'updatePassword'])->name('admin.update.password');
//--------------------------------------------banner---------------------------------------->

Route::get('/admin/banner', [BannerController::class, 'tbl_banner'])->name('admin.banner');
Route::post('/admin/banner', [BannerController::class, 'BannerForm'])->name('admin.banner.store');
Route::get('admin/manage_banners',[BannerController::class, 'index'])->name('admin.manage_banners');
Route::get('/admin/banner_edit/{banner_id}', [BannerController::class,'edit'])->name('admin.banners_edit');
Route::delete('/admin/manage_banners/{tbl_banner}', [BannerController::class, 'destroy'])->name('admin.manage_banners.destroy');
Route::put('/admin/banner/{id}', [BannerController::class, 'update'])->name('admin.banner.update');
Route::post('admin/status/{banner_id}/updateStatus', [BannerController::class, 'updateStatus'])->name('admin.status.update');


//--------------------------------------------PartnersDataView---------------------------------------->


Route::get('admin/manage-club-bar',[BarClubController::class, 'PartnewViewIndex'])->name('admin.manage-club-bar');
Route::get('/admin/view-club-bar/{partner_id}', [BarClubController::class,'edit'])->name('admin.view-club-bar');
Route::delete('/admin/manage-club-bar/{partnerData}', [BarClubController::class, 'destroy'])->name('admin.manage-club-bar.destroy');
Route::post('admin/update-request', [BarClubController::class, 'updateRequest'])->name('admin.update.request');

//--------------------------------------------CustomerDataView---------------------------------------->


Route::get('admin/manage-user',[UserController::class, 'CustomerViewIndex'])->name('admin.manage-user');
Route::get('/admin/user-view/{id}', [UserController::class,'ViewUser'])->name('admin.user-view');
Route::delete('/admin/user-view/{$customersData}', [UserController::class, 'destroy'])->name('admin.user-view.destroy');
Route::post('admin/update-request', [BarClubController::class, 'updateRequest'])->name('admin.update.request');

//--------------------------------------------OrderDataView---------------------------------------->

Route::get('admin/manage-order-list',[OrderListController::class, 'OrderViewIndex'])->name('admin.manage-order-list');
Route::get('/admin/view-order-list-details/{id}', [OrderListController::class,'ViewOrderList'])->name('admin.view-order-list-details');
Route::delete('/admin/user-view/{$customersData}', [UserController::class, 'destroy'])->name('admin.user-view.destroy');
Route::post('admin/update-request', [BarClubController::class, 'updateRequest'])->name('admin.update.request');
Route::get('/filter-data', [HomeController::class, 'showdata'])->name('filter.data');


Route::match(['get', 'head'], '/', [HomeController::class, 'showdata'])->name('home');
Route::get('partner-with-us', [HomeController::class, 'PartnerWithUs'])->name('partner-with-us');
Route::get('profile', [HomeController::class, 'ProfileHome'])->name('profile');
Route::post('partner-with-us', [PartnerWithUsController::class, 'PartnerRegisterFrom'])->name('partner-with-us.store');

// Partner Dashboard (Protected Route)
Route::get('/partner/{clubname}-{register_id}', [HomeController::class, 'PartnerDashBord'])
    ->name('partner-profile')
    ->middleware('partner.auth');
 // Use custom session-based middleware
Route::post('/partner/login', [PartnerWithUsController::class, 'partnerLogin'])->name('partner.login.submit');


// Partner Logout
Route::get('/partner/login', [PartnerWithUsController::class, 'showPartnerLoginForm'])->name('partner.login');
Route::get('/partner/logout', [PartnerWithUsController::class, 'partnerLogout'])->name('partner.logout');


Route::post('CustomerRegister', [CustomerController::class, 'CustomerRegisterFrom'])->name('customer.store');
Route::post('/verify-otp', [CustomerController::class, 'verifyOtp'])->name('customer.verify.otp');
Route::post('order-from', [OrderController::class, 'OrderFormData'])->name('order.form.data');
Route::get('/customer/{customername}-{register_id}', [HomeController::class, 'CustomerBookData'])
    ->name('profile')
    ->middleware('customer.auth');
// Route::get('/customer/{customername}-{register_id}', [HomeController::class, 'CustomerBookData'])
//     ->name('profile-dashboard')
//     ->middleware('customer.auth');
Route::get('/customer/logout', [CustomerController::class, 'customerLogout'])->name('customer.logout');
Route::post('offradd', [PartnerWithUsController::class, 'offerAdd'])->name('partner-offradd.store');
Route::post('/customer/login', [CustomerController::class, 'CustomerLogin'])->name('customer.login.submit');
Route::post('partner-info', [PartnerWithUsController::class, 'PartnerInfoAdd'])->name('partner-infoAdd.store');
Route::post('partner-infosecd', [PartnerWithUsController::class, 'PartnerSecdInfoAdd'])->name('partner-infoSecdAdd.store');
Route::post('/update-filters', [FiltersController::class, 'FilterFormData'])->name('update.filters');
Route::post('/customer/update', [CustomerController::class, 'CustomerDataUpdte'])->name('customer.update');


$club_urls = DB::table('partners')->select('location_url', 'bar_club_url')->get();

if ($club_urls->isNotEmpty()) {
    foreach ($club_urls as $club_url) {
        Route::get('/' . $club_url->location_url . '/' . $club_url->bar_club_url, 
            [HomeController::class, 'BarClubDetails']);
    }
}
Route::post('/partner-verify-otp', [PartnerWithUsController::class, 'PartnerverifyOtp']);

Route::post('/location/search-ajax', [SearchController::class, 'searchLocationsAjax'])->name('location.search.ajax');

Route::post('/bar-club/search-ajax', [SearchController::class, 'searchBarsAjax'])->name('search.ajax');

Route::get('/search-results', [SearchController::class, 'searchResults'])->name('search.results');
Route::post('/submit-review', [ReviewController::class, 'ReviewFormData'])->name('review-form-submit');

Route::post('/approve-review', [ReviewController::class, 'approveReview'])->name('approve-review');
